==> blancoNLpackGenerator-0.0.94-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorTranslationFragmentToPleiadesProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcefile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [conf/BlancoNLpackGeneratorTranslationFragment.csv]<br>
     * ̓t@CB
     */
    private String fSourcefile = "conf/BlancoNLpackGeneratorTranslationFragment.csv";

    /**
     * tB[h [targetfile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp/BlancoNLpackGeneratorTranslationFragment.properties]<br>
     * o̓t@CB
     */
    private String fTargetfile = "tmp/BlancoNLpackGeneratorTranslationFragment.properties";

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     */
    private String fSourcedir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     */
    private String fTargetdir;

    /**
     * tB[h [contributor]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [<contributor>]<br>
     * v҂̖OB
     */
    private String fContributor = "<contributor>";

    /**
     * tB[h [isoutputdate]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * to͂邩ǂB
     */
    private boolean fIsoutputdate = true;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcefile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@CB
     *
     * @param argSourcefile tB[h[sourcefile]Ɋi[l
     */
    public void setSourcefile(final String argSourcefile) {
        fSourcefile = argSourcefile;
    }

    /**
     * tB[h[sourcefile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [conf/BlancoNLpackGeneratorTranslationFragment.csv]<br>
     * ̓t@CB
     *
     * @return tB[h[sourcefile]Ɋi[Ăl
     */
    public String getSourcefile() {
        return fSourcefile;
    }

    /**
     * tB[h [targetfile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@CB
     *
     * @param argTargetfile tB[h[targetfile]Ɋi[l
     */
    public void setTargetfile(final String argTargetfile) {
        fTargetfile = argTargetfile;
    }

    /**
     * tB[h[targetfile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp/BlancoNLpackGeneratorTranslationFragment.properties]<br>
     * o̓t@CB
     *
     * @return tB[h[targetfile]Ɋi[Ăl
     */
    public String getTargetfile() {
        return fTargetfile;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [contributor]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * v҂̖OB
     *
     * @param argContributor tB[h[contributor]Ɋi[l
     */
    public void setContributor(final String argContributor) {
        fContributor = argContributor;
    }

    /**
     * tB[h[contributor]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [<contributor>]<br>
     * v҂̖OB
     *
     * @return tB[h[contributor]Ɋi[Ăl
     */
    public String getContributor() {
        return fContributor;
    }

    /**
     * tB[h [isoutputdate]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * to͂邩ǂB
     *
     * @param argIsoutputdate tB[h[isoutputdate]Ɋi[l
     */
    public void setIsoutputdate(final boolean argIsoutputdate) {
        fIsoutputdate = argIsoutputdate;
    }

    /**
     * tB[h[isoutputdate]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * to͂邩ǂB
     *
     * @return tB[h[isoutputdate]Ɋi[Ăl
     */
    public boolean getIsoutputdate() {
        return fIsoutputdate;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcefile=" + fSourcefile);
        buf.append(",targetfile=" + fTargetfile);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",contributor=" + fContributor);
        buf.append(",isoutputdate=" + fIsoutputdate);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.9-src.zip: src/blanco/nlpack/generator/task/valueobject/BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.task.valueobject;

/**
 * NX [BlancoNLpackGeneratorTranslationFragmentToPleiadesProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcefile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [conf/BlancoNLpackGeneratorTranslationFragment.csv]<br>
     * ̓t@CB
     */
    private String fSourcefile = "conf/BlancoNLpackGeneratorTranslationFragment.csv";

    /**
     * tB[h [targetfile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp/BlancoNLpackGeneratorTranslationFragment.properties]<br>
     * o̓t@CB
     */
    private String fTargetfile = "tmp/BlancoNLpackGeneratorTranslationFragment.properties";

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     */
    private String fSourcedir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     */
    private String fTargetdir;

    /**
     * tB[h [contributor]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [<contributor>]<br>
     * v҂̖OB
     */
    private String fContributor = "<contributor>";

    /**
     * tB[h [isoutputdate]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * to͂邩ǂB
     */
    private boolean fIsoutputdate = true;

    /**
     * tB[h [ischeckbundleuriasbabel]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * BundleURI babel: n܂Ă邱ƂmF邩ǂB
     */
    private boolean fIscheckbundleuriasbabel = true;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcefile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@CB
     *
     * @param argSourcefile tB[h[sourcefile]Ɋi[l
     */
    public void setSourcefile(final String argSourcefile) {
        fSourcefile = argSourcefile;
    }

    /**
     * tB[h[sourcefile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [conf/BlancoNLpackGeneratorTranslationFragment.csv]<br>
     * ̓t@CB
     *
     * @return tB[h[sourcefile]Ɋi[Ăl
     */
    public String getSourcefile() {
        return fSourcefile;
    }

    /**
     * tB[h [targetfile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@CB
     *
     * @param argTargetfile tB[h[targetfile]Ɋi[l
     */
    public void setTargetfile(final String argTargetfile) {
        fTargetfile = argTargetfile;
    }

    /**
     * tB[h[targetfile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [tmp/BlancoNLpackGeneratorTranslationFragment.properties]<br>
     * o̓t@CB
     *
     * @return tB[h[targetfile]Ɋi[Ăl
     */
    public String getTargetfile() {
        return fTargetfile;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ̓t@Ci[ꂽfBNgBsourcefileꂩwB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o̓t@Ci[ꂽfBNgBtargetfileꂩwB
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [contributor]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * v҂̖OB
     *
     * @param argContributor tB[h[contributor]Ɋi[l
     */
    public void setContributor(final String argContributor) {
        fContributor = argContributor;
    }

    /**
     * tB[h[contributor]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Kl   [<contributor>]<br>
     * v҂̖OB
     *
     * @return tB[h[contributor]Ɋi[Ăl
     */
    public String getContributor() {
        return fContributor;
    }

    /**
     * tB[h [isoutputdate]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * to͂邩ǂB
     *
     * @param argIsoutputdate tB[h[isoutputdate]Ɋi[l
     */
    public void setIsoutputdate(final boolean argIsoutputdate) {
        fIsoutputdate = argIsoutputdate;
    }

    /**
     * tB[h[isoutputdate]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * to͂邩ǂB
     *
     * @return tB[h[isoutputdate]Ɋi[Ăl
     */
    public boolean getIsoutputdate() {
        return fIsoutputdate;
    }

    /**
     * tB[h [ischeckbundleuriasbabel]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * BundleURI babel: n܂Ă邱ƂmF邩ǂB
     *
     * @param argIscheckbundleuriasbabel tB[h[ischeckbundleuriasbabel]Ɋi[l
     */
    public void setIscheckbundleuriasbabel(final boolean argIscheckbundleuriasbabel) {
        fIscheckbundleuriasbabel = argIscheckbundleuriasbabel;
    }

    /**
     * tB[h[ischeckbundleuriasbabel]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * BundleURI babel: n܂Ă邱ƂmF邩ǂB
     *
     * @return tB[h[ischeckbundleuriasbabel]Ɋi[Ăl
     */
    public boolean getIscheckbundleuriasbabel() {
        return fIscheckbundleuriasbabel;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslationFragmentToPleiadesProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcefile=" + fSourcefile);
        buf.append(",targetfile=" + fTargetfile);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",contributor=" + fContributor);
        buf.append(",isoutputdate=" + fIsoutputdate);
        buf.append(",ischeckbundleuriasbabel=" + fIscheckbundleuriasbabel);
        buf.append("]");
        return buf.toString();
    }
}
